@@ -2,6 +2,7 @@ from .circular_linked_list import CircularLinkedList
 from .doubly_circular_list import DoublyCircularList
 from .doubly_linked_list import DoublyNode, DoublyLinkedList
 from .linked_list import LinkedList, Node
+from .lru_cache import LRUCache
 from .queue import Queue
 
 __all__ = [
@@ -9,5 +10,6 @@ __all__ = [
     'DoublyLinkedList', 'DoublyNode',
     'CircularLinkedList',
     'DoublyCircularList',
-    'Queue'
+    'Queue',
+    'LRUCache'
 ]
