@@ -1,16 +1,18 @@
+# Min Heap Tree Implementation
+from __future__ import annotations
+
+from typing import Any
+
 from datastax.trees.heap_tree import HeapTree, HeapTreeNode
 
 
-# from heap_tree import HeapTree, HeapTreeNode
-
-
 class MinHeapTree(HeapTree):
-    def heapify(self, node: HeapTreeNode) -> None:
+    def _heapify(self, node: HeapTreeNode) -> None:
         if node.parent and node.parent.data > node.data:
             node.parent.data, node.data = node.data, node.parent.data
-            self.heapify(node.parent)
-    
-    def shift_up(self, node: HeapTreeNode) -> None:
+            self._heapify(node.parent)
+
+    def _shift_up(self, node: HeapTreeNode) -> None:
         root = node
         left_child = root.left
         right_child = root.right
@@ -18,6 +20,10 @@ class MinHeapTree(HeapTree):
             root = left_child
         if right_child and right_child.data < root.data:
             root = right_child
-        if root is node: return
+        if root is node:
+            return
         root.data, node.data = node.data, root.data
-        self.shift_up(root)
+        self._shift_up(root)
+
+    def insert_path(self, data: Any, path: list[str] = None) -> None:
+        raise NotImplementedError
